@@ -21,11 +21,11 @@
 #ifndef UDEVQTDEVICE_H
 #define UDEVQTDEVICE_H
 
-#include <QtCore/QObject>
-#include <QtCore/QList>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QVariant>
+#include <QObject>
+#include <QList>
+#include <QString>
+#include <QStringList>
+#include <QVariant>
 
 namespace UdevQt
 {
@@ -60,7 +60,7 @@ class Device
         Device ancestorOfType(const QString &subsys, const QString &devtype) const;
 
     private:
-        Device(DevicePrivate *devPrivate);
+        explicit Device(DevicePrivate *devPrivate);
         friend class Client;
         friend class ClientPrivate;
 
